import { Tree } from '@angular-devkit/schematics';
import * as ts from 'typescript/lib/tsserverlibrary';
/**
 * Langauge server host is responsible for **most** of the FS operations / checks
 * Angular's Ivy LS sometimes bypasses these, calling path methods instead of tsLsHost operations
 */
export declare class ServerHost implements ts.server.ServerHost {
    private host;
    readonly args: string[];
    readonly newLine: string;
    readonly useCaseSensitiveFileNames: boolean;
    constructor(host: Tree);
    /**
     * Read a file's content from the Virtual Tree
     * If file does not exist in virtual tree, check in physical FS
     */
    readFile(path: string, encoding?: string): string | undefined;
    getFileSize(path: string): number;
    watchFile(path: string, callback: ts.FileWatcherCallback, pollingInterval?: number): ts.FileWatcher;
    watchDirectory(path: string, callback: ts.DirectoryWatcherCallback, recursive?: boolean): ts.FileWatcher;
    resolvePath(path: string): string;
    /**
     * Checks for file in Virtual Tree w/ relative path
     * If file does not exist in virtual tree, check in physical FS
     */
    fileExists(path: string): boolean;
    directoryExists(path: string): boolean;
    getExecutingFilePath(): string;
    getCurrentDirectory(): string;
    /**
     * Get all subdirs of a directory from the Tree mapped to absolute paths
     */
    getDirectories(path: string): string[];
    /**
     * Get all files of a directory from the Tree mapped to absolute paths
     */
    readDirectory(path: string): string[];
    require(initialPath: string, moduleName: string): {
        module: any;
        error: any;
    } | {
        module: any;
        error: Error;
    };
    getModifiedTime(path: string): Date | undefined;
    realpath(path: string): string;
    createSHA256Hash(data: string): string;
    write(_data: string): void;
    writeOutputIsTTY(): boolean;
    writeFile(_path: string, _data: string, _writeByteOrderMark?: boolean): void;
    createDirectory(_path: string): void;
    setModifiedTime(_path: string, _time: Date): void;
    deleteFile(_path: string): void;
    createHash(_data: string): string;
    getMemoryUsage(): number;
    exit(_exitCode?: number): void;
    setTimeout(_callback: (...argsv: any[]) => void, _ms: number, ..._args: any[]): any;
    clearTimeout(_timeoutId: any): void;
    clearScreen(): void;
    base64decode(_input: string): string;
    base64encode(_input: string): string;
    setImmediate(_callback: (...argsv: any[]) => void, ..._args: any[]): any;
    clearImmediate(_timeoutId: any): void;
}
